
# Slot: occurs_in

The cellular location in which the activity occurs

URI: [gocam:activity__occurs_in](https://w3id.org/gocam/activity__occurs_in)


## Domain and Range

None &#8594;  <sub>0..1</sub> [CellularAnatomicalEntityAssociation](CellularAnatomicalEntityAssociation.md)

## Parents


## Children


## Used by

 * [Activity](Activity.md)
